aeiou
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Pronounced “[ayoo](https://youtu.be/Hv6RbEOlqRo?t=24)”

## Install

It is recommended you install the latest version from GitHub via

``` sh
pip install git+https://github.com/drscotthawley/aeiou.git
```

However binaries will be occasionally updated on PyPI, installed via

``` sh
pip install aeiou
```

## How to use

This is a series of utility routines developed in support of multiple
projects within the [Harmonai](https://www.harmonai.org/) organization.
See individual documentation pages for more specific instructions on how
these can be used. Note that this is *research code*, so it’s a) in flux
and b) in need of improvements to documenation.

## Documentation

Documentation for this library is hosted on the [aeiou GitHub Pages
site](https://drscotthawley.github.io/aeiou/).

## Contributing

Contributions are welcome – especially for improvements to
documentation! To contribute:

1.  Fork this repo and then clone your fork to your local machine.

2.  Create a new (local) branch: `git -b mybranch` (or whatever you want
    to call it).

3.  This library is written entirely in [nbdev](https://nbdev.fast.ai/)
    version 2, using Jupyter notebooks.

4.  [Install nbdev](https://nbdev.fast.ai/getting_started.html#install)
    and then you can edit the Jupyter notebooks.

5.  After editing notebooks, run `nbdev_prepare`

6.  If that succeeds, you can do
    `git add *.ipynb aeiou/*.py; git commit` and then `git push` to get
    your changes to back to your fork on GitHub.

7.  Then send a Pull Request from your fork to the main `aeiou`
    repository.

## Attribution

Please include attribution of this code if you reproduce sections of it
in your own code:

    aeiou: audio engineering i/o utilities: Copyright (c) Scott H. Hawley, 2022-2023. https://github.com/drscotthawley/aeiou

In research papers, please cite this software if you find it useful:

``` bibtex
@misc{aeiou,
  author = {Scott H. Hawley},
  title = {aeiou: audio engineering i/o utilities},
  year  = {2022},
  url   = {https://github.com/drscotthawley/aeiou},
}
```

Copyright (c) Scott H. Hawley, 2022-2023.

## License

[License](https://github.com/drscotthawley/aeiou/blob/main/LICENSE) is
APACHE 2.0.
